@@ -69,6 +69,8 @@ public:
 	virtual bool mouseMoveEvent(QMouseEvent *event, QEditor *editor);
 	virtual bool contextMenuEvent(QContextMenuEvent *event, QEditor *editor);
 private:
+	bool runMacros(QKeyEvent *event, QEditor *editor);
+	bool autoInsertLRM(QKeyEvent *event, QEditor *editor);
 	friend class LatexEditorView;
 	const LatexCompleterConfig* completerConfig;
 	const LatexEditorViewConfig* editorViewConfig;
@@ -83,6 +85,66 @@ private:
 
 static const QString LRMStr = QChar(LRM);
 
+bool DefaultInputBinding::runMacros(QKeyEvent *event, QEditor *editor) {
+	Q_ASSERT(completerConfig);
+	QLanguageDefinition *language = editor->document() ? editor->document()->languageDefinition() : 0;
+	QDocumentLine line = editor->cursor().selectionStart().line();
+	int column = editor->cursor().selectionStart().columnNumber();
+	QString prev = line.text().mid(0, column) + event->text(); //TODO: optimize
+	foreach (const Macro &m, completerConfig->userMacros) {
+		if (!m.isActiveForTrigger(Macro::ST_REGEX)) continue;
+		if (!m.isActiveForLanguage(language)) continue;
+		if (!(m.isActiveForFormat(line.getFormatAt(column)) || (column > 0 && m.isActiveForFormat(line.getFormatAt(column-1))))) continue; //two checks, so it works at beginning and end of an environment
+		QRegExp& r = const_cast<QRegExp&>(m.triggerRegex);//a const qregexp doesn't exist
+		if (r.indexIn(prev)!=-1){
+			QDocumentCursor c = editor->cursor();
+			bool block = false;
+			int realMatchLen = r.matchedLength();
+			if (m.triggerLookBehind) realMatchLen -= r.cap(1).length();
+			if (c.hasSelection() || realMatchLen > 1)
+				block = true;
+			if (block) editor->document()->beginMacro();
+			if (c.hasSelection()) c.removeSelectedText();
+			if (m.triggerRegex.matchedLength() > 1) {
+				c.movePosition(realMatchLen-1, QDocumentCursor::PreviousCharacter, QDocumentCursor::KeepAnchor);
+				c.removeSelectedText();
+			}
+
+			LatexEditorView* view = editor->property("latexEditor").value<LatexEditorView*>();
+			REQUIRE_RET(view, true);
+			view->insertMacro(m.tag, r, Macro::ST_REGEX);
+			//editor->insertText(c, m.tag);
+			if (block) editor->document()->endMacro();
+			editor->emitCursorPositionChanged(); //prevent rogue parenthesis highlightations
+			/*			if (editor->languageDefinition())
+editor->languageDefinition()->clearMatches(editor->document());
+*/
+			return true;
+		}
+	}
+	return false;
+}
+
+bool DefaultInputBinding::autoInsertLRM(QKeyEvent *event, QEditor *editor) {
+	const QString & text = event->text();
+	if (editorViewConfig->autoInsertLRM && text.length() == 1 && editor->cursor().isRTL()) {
+		if (text.at(0) == '}') {
+			bool autoOverride = editor->isAutoOverrideText("}");
+			bool previousIsLRM = editor->cursor().previousChar().unicode() == LRM;
+			bool block = previousIsLRM || autoOverride;
+			if (block) editor->document()->beginMacro();
+			if (previousIsLRM) editor->cursor().deletePreviousChar(); //todo mirrors
+			if (autoOverride) {
+				editor->write("}"); //separated, so autooverride works
+				editor->write(LRMStr);
+			} else editor->write("}"+LRMStr);
+			if (block) editor->document()->endMacro();
+			return true;
+		}
+	}
+	return false;
+}
+
 bool DefaultInputBinding::keyPressEvent(QKeyEvent *event, QEditor *editor) {
 	if (LatexEditorView::completer && LatexEditorView::completer->acceptTriggerString(event->text()) &&
 	              (editor->currentPlaceHolder() < 0 || editor->currentPlaceHolder() >= editor->placeHolderCount() || editor->getPlaceHolder(editor->currentPlaceHolder()).mirrors.isEmpty() ||  editor->getPlaceHolder(editor->currentPlaceHolder()).affector != BracketInvertAffector::instance()))  {
@@ -97,69 +159,11 @@ bool DefaultInputBinding::keyPressEvent(QKeyEvent *event, QEditor *editor) {
 		else LatexEditorView::completer->complete(editor,0);
 		return true;
 	}
-	QString text = event->text();
-	if (!text.isEmpty()) {
-		Q_ASSERT(completerConfig); 
-		QLanguageDefinition *language = editor->document() ? editor->document()->languageDefinition() : 0;
-		QDocumentLine line = editor->cursor().selectionStart().line();
-		int column = editor->cursor().selectionStart().columnNumber();
-		QString prev = line.text().mid(0, column)+text; //TODO: optimize
-		for (int i=0;i<completerConfig->userMacro.size();i++) {
-			const Macro& m = completerConfig->userMacro[i];			
-			if (m.trigger.isEmpty() || !(m.triggers & Macro::ST_REGEX)) continue;
-			if (!m.triggerLanguage.isEmpty() && !m.triggerLanguages.contains(language)) 
-				continue;
-			if (!m.triggerFormatsUnprocessed.isEmpty()) const_cast<Macro&>(completerConfig->userMacro[i]).initTriggerFormats();
-			if (!m.triggerFormats.isEmpty() && (
-					 (!m.triggerFormats.contains(line.getFormatAt(column)) &&
-						!(column > 0 && m.triggerFormats.contains(line.getFormatAt(column-1)))))) //two checks, so it works at beginning and end of an environment
-				continue;
-			QRegExp& r = const_cast<QRegExp&>(m.triggerRegex);//a const qregexp doesn't exist
-			if (r.indexIn(prev)!=-1){
-				QDocumentCursor c = editor->cursor();
-				bool block = false;
-				int realMatchLen = r.matchedLength();
-				if (m.triggerLookBehind) realMatchLen -= r.cap(1).length();
-				if (c.hasSelection() || realMatchLen > 1)
-					block = true;
-				if (block) editor->document()->beginMacro();
-				if (c.hasSelection()) c.removeSelectedText();
-				if (completerConfig->userMacro[i].triggerRegex.matchedLength() > 1) {
-					c.movePosition(realMatchLen-1, QDocumentCursor::PreviousCharacter, QDocumentCursor::KeepAnchor);
-					c.removeSelectedText();
-				}
-				
-				LatexEditorView* view = editor->property("latexEditor").value<LatexEditorView*>();
-				REQUIRE_RET(view, true);
-				view->insertMacro(completerConfig->userMacro[i].tag, r, Macro::ST_REGEX);
-				//editor->insertText(c, completerConfig->userMacro[i].tag);
-				if (block) editor->document()->endMacro();
-				editor->emitCursorPositionChanged(); //prevent rogue parenthesis highlightations
-				/*			if (editor->languageDefinition())
-  editor->languageDefinition()->clearMatches(editor->document());
-*/
-				return true;
-			}
-
-			if (editorViewConfig->autoInsertLRM && text.length() == 1 && editor->cursor().isRTL()) {
-				if (text.at(0) == '}') {
-					bool autoOverride = editor->isAutoOverrideText("}");
-					bool previousIsLRM = editor->cursor().previousChar().unicode() == LRM;
-					bool block = previousIsLRM || autoOverride;
-					if (block) editor->document()->beginMacro();
-					if (previousIsLRM) editor->cursor().deletePreviousChar(); //todo mirrors
-					if (autoOverride) {
-						editor->write("}"); //separated, so autooverride works
-						editor->write(LRMStr);
-					} else editor->write("}"+LRMStr);
-					if (block) editor->document()->endMacro();
-					return true;
-				}
-			}
-
-		}
-		//		for (int i=0;i<LatexEditorView::completer)
-		
+	if (!event->text().isEmpty()) {
+		if (runMacros(event, editor))
+			return true;
+		if (autoInsertLRM(event, editor))
+			return true;
 	} else {
 		if (event->key() == Qt::Key_Control) {
 			editor->setMouseTracking(true);
@@ -807,7 +811,7 @@ void LatexEditorView::displayLineGrammarErrorsInternal(int lineNr, const QList<G
 			if (grammarFormatsDisabled[index]) continue;
 			f = grammarFormats[index];
 		}
-		if (config->hideNonTextGrammarErrors && (isNonTextFormat(line.getFormatAt(error.offset)) || isNonTextFormat(error.offset+error.length-1)))
+		if (config->hideNonTextGrammarErrors && (isNonTextFormat(line.getFormatAt(error.offset)) || isNonTextFormat(line.getFormatAt(error.offset+error.length-1))))
 			continue;
 		line.addOverlay(QFormatRange(error.offset,error.length,f));
 	}
@@ -1261,80 +1265,36 @@ void LatexEditorView::openExternalFile(){
 }
 
 void LatexEditorView::openPackageDocumentation(QString package){
-    QString command;
+	QString command;
 	if (package.isEmpty()) {
 		QAction *act = qobject_cast<QAction*>(sender());
 		if (!act) return;
 		package = act->data().toString();
 	}
-    if(package.contains("#")){
-        int i=package.indexOf("#");
-        command=package.mid(i+1);
-        package=package.left(i);
-    }
-    // replace some package denominations
-    if(package=="latex-document"||package=="latex-dev"||package=="latex-mathsymbols")
-        package="latex2e";
-    if(package=="class-scrartcl,scrreprt,scrbook")
-        package="scrartcl";
-    if(package.startsWith("class-"))
-        package=package.mid(6);
-	if (!package.isEmpty()) {
-        if(config->texdocHelpInInternalViewer){
-            QStringList args;
-            if(Help::isMiktexTexdoc()){
-                args << "--list-only";
-            }
-            else {
-                args << "--list" << "--machine";
-            }
-            args << package;
-            QProcess proc(this);
-            //connect(&proc, SIGNAL(readyReadStandardError()), this, SLOT(openPackageDocumentationError()));
-            proc.start("texdoc", args);
-            if (!proc.waitForFinished(2000)) {
-                txsWarning(QString(tr("texdoc took too long to open the documentation for the package:")+"\n%1").arg(package));
-                return;
-            }
-            QString output=proc.readAllStandardOutput();
-	    if(Help::isMiktexTexdoc()){
-		QStringList lst=output.split("\r\n");
-		for(int i=0;i<lst.count();i++){
-		    output=lst.at(i);
-		    if(output.endsWith(".pdf"))
-			emit openInternalDocViewer(output,command);
-		}
-	    }else{
-		QStringList lst=output.split("\n");
-		if(lst.count()>0){
-		    output=lst.first();
-		    output=output.simplified();
-		    lst=output.split(" ");
-		    if(lst.count()>2){
-			output=lst.at(2);
-			if(output.endsWith(".pdf"))
-			    emit openInternalDocViewer(output,command);
-		    }
-		}
-	    }
-        }else{
-            QStringList args;
-            args << "--view" << package;
-            QProcess proc(this);
-            connect(&proc, SIGNAL(readyReadStandardError()), this, SLOT(openPackageDocumentationError()));
-            proc.start("texdoc", args);
-            if (!proc.waitForFinished(2000)) {
-                txsWarning(QString(tr("texdoc took too long to open the documentation for the package:")+"\n%1").arg(package));
-                return;
-            }
-        }
+	if (package.contains("#")) {
+		int i = package.indexOf("#");
+		command = package.mid(i+1);
+		package = package.left(i);
 	}
-}
-
-void LatexEditorView::openPackageDocumentationError() {
-	QProcess *proc = qobject_cast<QProcess*>(sender());
-	if (proc) {
-		txsWarning(proc->readAllStandardError());
+	// replace some package denominations
+	if (package=="latex-document" || package=="latex-dev" || package=="latex-mathsymbols")
+		package = "latex2e";
+	if (package=="class-scrartcl,scrreprt,scrbook")
+		package = "scrartcl";
+	if (package.startsWith("class-"))
+		package = package.mid(6);
+	if (!package.isEmpty()) {
+		if(config->texdocHelpInInternalViewer) {
+			QString docfile = Help::packageDocFile(package);
+			if (docfile.isEmpty())
+				return;
+			if (docfile.endsWith(".pdf"))
+				emit openInternalDocViewer(docfile, command);
+			else
+				Help::instance()->viewTexdoc(package); // fallback e.g. for dvi
+		}else{
+			Help::instance()->viewTexdoc(package);
+		}
 	}
 }
 
@@ -2149,44 +2109,16 @@ void LatexEditorView::insertHardLineBreaks(int newLength, bool smartScopeSelecti
 		}
 	}
 	if (joinLines) { // start of smart formatting, similar to what emacs (AucTeX) can do, but much simple
-		QStringList lines;  QString tmpLine;
-		for (int i=startLine; i <= endLine; i++)  {
-			QString fullString  = doc->line(i).text();
-			int commentStart    = LatexParser::commentStart(fullString);
-			if (commentStart==-1) {
-				tmpLine.append(" ");
-				tmpLine.append(fullString);
-			} else {
-				lines << tmpLine;
-				lines << fullString;
-				tmpLine.clear();
-			}
-		}
-		lines.append(tmpLine);
-		lines[0].remove(0,1); // remove needless space character from first line
-		
-		QStringList formattedList;
-		for (int i=0; i < lines.size(); i++) {
-			QString bigString = lines.at(i);
-			while (bigString.size() > newLength) {
-				int breakAt=bigString.lastIndexOf(breakChars,newLength);
-				formattedList << bigString.left(breakAt);
-				if (breakAt >= 0) {
-					bigString.remove(0, breakAt+1);
-				} else {
-					bigString.clear();
-					break;
-				}
-			}
-			if (bigString.size() > 0)  formattedList << bigString;
-		}
-		
+		QStringList lines;
+		for (int i=startLine; i <= endLine; i++)
+			lines << doc->line(i).text();
+		lines = joinLinesExceptCommentsAndEmptyLines(lines);
+		lines = splitLines(lines, newLength, breakChars);
+
 		QDocumentCursor vCur = doc->cursor(startLine, 0, endLine, doc->line(endLine).length());
-		editor->insertText(vCur,formattedList.join("\n"));
-		
+		editor->insertText(vCur, lines.join("\n"));
 		editor->setCursor(cur);
-		
-		return ;
+		return;
 	}
 	
 	bool areThereLinesToBreak=false;
@@ -2429,7 +2361,6 @@ void LatexEditorViewConfig::settingsChanged(){
 	
 	lastFontFamily = fontFamily;
 	lastFontSize = fontSize;
-	
 }
 
 
