@@ -334,7 +334,75 @@ QString& parseTexOrPDFString(QString& s) {
 	return s;
 }
 
-bool localAwareLessThan(const QString &s1, const QString &s2) {
+// joins all the input lines trimming whitespace. A new line is started on comments and empty lines
+QStringList joinLinesExceptCommentsAndEmptyLines(const QStringList& lines) {
+#define flush_tmpLine() if (!tmpLine.isEmpty()) { joinedLines.append(tmpLine); tmpLine.clear(); }
+
+	QStringList joinedLines;
+	QString tmpLine;
+	foreach (const QString &l, lines) {
+		QString rtrimmedLine = trimRight(l);
+
+		if (rtrimmedLine.isEmpty()) { // empty line as separator
+			flush_tmpLine();
+			joinedLines.append(rtrimmedLine);
+			continue;
+		}
+
+		if (tmpLine.isEmpty()) {
+			tmpLine.append(rtrimmedLine);
+		} else {
+			tmpLine.append(" " + rtrimmedLine.trimmed());
+		}
+		int commentStart = LatexParser::commentStart(rtrimmedLine);
+		if (commentStart >= 0) {
+			flush_tmpLine();
+		}
+	}
+	flush_tmpLine();
+	return joinedLines;
+}
+
+// splits lines after maximal number of chars while keeping track of indentation and comments
+QStringList splitLines(const QStringList& lines, int maxCharPerLine, const QRegExp& breakChars) {
+	QStringList splittedLines;
+	int maxIndent = maxCharPerLine / 2 * 3;
+	foreach (QString line, lines) {
+		int textStart = 0;
+		while (textStart < line.length() && line.at(textStart).isSpace() && textStart < maxIndent) textStart++;
+		if (textStart >= line.length()) { // empty line
+			splittedLines << line;
+			continue;
+		}
+		int maxCharPerLineWithoutIndent = maxCharPerLine - textStart;
+		QString indent = line.left(textStart);
+		line = line.mid(textStart);
+
+		bool inComment = false;
+		while (line.length() > maxCharPerLineWithoutIndent) {
+			if (inComment) line.prepend("% ");
+			int breakAt = line.lastIndexOf(breakChars, maxCharPerLineWithoutIndent);
+			if (breakAt <= 3) breakAt = -1;
+			QString leftPart = line.left(breakAt);
+			splittedLines << indent + leftPart;
+			if (breakAt >= 0) {
+				line.remove(0, breakAt+1);
+				inComment = inComment || (LatexParser::commentStart(leftPart) >= 0);
+			} else {
+				line.clear();
+				break;
+			}
+		}
+		if (line.length() > 0) {
+			if (inComment) line.prepend("% ");
+			splittedLines << indent + line;
+		}
+	}
+	return splittedLines;
+}
+
+
+bool localeAwareLessThan(const QString &s1, const QString &s2) {
 	return QString::localeAwareCompare(s1,s2)<0;
 }
 
@@ -1418,64 +1486,70 @@ LatexPackage loadCwlFile(const QString fileName,LatexCompleterConfig *config) {
 			    valid.remove('S');
 			}
 		    }
-		    // parse for spell checkable commands
-		    int res=rxCom.indexIn(line);
-		    if(keywords.contains(rxCom.cap(3))){
-			package.optionCommands << rxCom.cap(1);
-		    }
-		    rxCom2.indexIn(line); // for commands which don't have a braces part e.g. \item[text]
-		    if(keywords.contains(rxCom2.cap(2))){
-			package.optionCommands << rxCom2.cap(1);
-		    }
-		    if(valid.contains('d')){ // definition command
-			if(res>-1){
-			    package.possibleCommands["%definition"] << rxCom.cap(1);
-			}
-			valid.remove('d');
-		    }
-		    if(valid.contains('i')){ // include like command
-			if(res>-1){
-			    package.possibleCommands["%include"] << rxCom.cap(1);
-			}
-			valid.remove('i');
-		    }
-		    if(valid.contains('l')){ // label command
-			if(res>-1){
-			    package.possibleCommands["%label"] << rxCom.cap(1);
-			}
-			valid.remove('l');
-		    }
-		    if(valid.contains('r')){ // ref command
-			if(res>-1){
-			    package.possibleCommands["%ref"] << rxCom.cap(1);
-			}
-			valid.remove('r');
-		    }
-		    if(valid.contains('c')){ // cite command
-			if(res>-1){
-			    package.possibleCommands["%cite"] << rxCom.cap(1);
-			}
-			valid.remove('c');
-		    }
-		    if(valid.contains('g')){ // definition command
-			if(res>-1){
-			    package.possibleCommands["%graphics"] << rxCom.cap(1);
-			}
-			valid.remove('g');
-		    }
-		    if(valid.contains('u')){ // usepackage command
-			if(res>-1){
-			    package.possibleCommands["%usepackage"] << rxCom.cap(1);
-			}
-			valid.remove('u');
-		    }
-		    if(valid.contains('b')){ // usepackage command
-			if(res>-1){
-			    package.possibleCommands["%bibliography"] << rxCom.cap(1);
-			    package.possibleCommands["%file"] << rxCom.cap(1);
-			}
-			valid.remove('b');
-		    }
+            // parse for spell checkable commands
+            int res=rxCom.indexIn(line);
+            if(keywords.contains(rxCom.cap(3))){
+                package.optionCommands << rxCom.cap(1);
+            }
+            rxCom2.indexIn(line); // for commands which don't have a braces part e.g. \item[text]
+            if(keywords.contains(rxCom2.cap(2))){
+                package.optionCommands << rxCom2.cap(1);
+            }
+            if(valid.contains('d')){ // definition command
+                if(res>-1){
+                    package.possibleCommands["%definition"] << rxCom.cap(1);
+                }
+                valid.remove('d');
+            }
+            if(valid.contains('i')){ // include like command
+                if(res>-1){
+                    package.possibleCommands["%include"] << rxCom.cap(1);
+                }
+                valid.remove('i');
+            }
+            if(valid.contains('l')){ // label command
+                if(res>-1){
+                    package.possibleCommands["%label"] << rxCom.cap(1);
+                }
+                valid.remove('l');
+            }
+            if(valid.contains('r')){ // ref command
+                if(res>-1){
+                    package.possibleCommands["%ref"] << rxCom.cap(1);
+                }
+                valid.remove('r');
+            }
+            if(valid.contains('c')){ // cite command
+                if(res>-1){
+                    package.possibleCommands["%cite"] << rxCom.cap(1);
+                }
+                valid.remove('c');
+            }
+            if(valid.contains('g')){ // definition command
+                if(res>-1){
+                    package.possibleCommands["%graphics"] << rxCom.cap(1);
+                }
+                valid.remove('g');
+            }
+            if(valid.contains('u')){ // usepackage command
+                if(res>-1){
+                    package.possibleCommands["%usepackage"] << rxCom.cap(1);
+                }
+                valid.remove('u');
+            }
+            if(valid.contains('b')){ // usepackage command
+                if(res>-1){
+                    package.possibleCommands["%bibliography"] << rxCom.cap(1);
+                    package.possibleCommands["%file"] << rxCom.cap(1);
+                }
+                valid.remove('b');
+            }
+            if(valid.contains('U')){ // url command
+                if(res>-1){
+                    package.possibleCommands["%url"] << rxCom.cap(1);
+                }
+                valid.remove('U');
+            }
 		    // normal commands for syntax checking
 		    // will be extended to distinguish between normal and math commands
 		    if(valid.isEmpty() || valid.contains('n')){
