@@ -51,8 +51,11 @@ QString textToLatex(const QString& text);
 // replaces \texorpdfstring{tex}{pdfString} with pdfString
 QString& parseTexOrPDFString(QString& s);
 
-//compares two strings local aware
-bool localAwareLessThan(const QString &s1, const QString &s2);
+QStringList joinLinesExceptCommentsAndEmptyLines(const QStringList& lines);
+QStringList splitLines(const QStringList& lines, int maxCharPerLine, const QRegExp& breakChars);
+
+//compares two strings locale aware
+bool localeAwareLessThan(const QString &s1, const QString &s2);
 
 // true for characters that are valid in latex command names, e.g. \section*
 inline bool isCommandChar(const QChar &c) { return c.isLetter() || c=='*'; }
