@@ -196,6 +196,7 @@ private slots:
 	void relayToOwnSlot();
 	void autoRunScripts();
 	void runScripts(int trigger);
+	void runScriptsInList(int trigger, const QList<Macro> &scripts);
 	
 protected slots:
 	void fileNew(QString fileName="");
@@ -203,12 +204,12 @@ protected slots:
 	void fileMakeTemplate();
 	void fileOpen();
 	void fileRestoreSession(bool showProgress = true);
-	void fileSave();
+    void fileSave(const bool saveSilently=false);
 	void fileSaveAll();
 	void fileSaveAll(bool alsoUnnamedFiles, bool alwaysCurrentFile);
 private slots:
 	void fileNewInternal(QString fileName="");
-	void fileSaveAs(const QString& fileName = "");
+    void fileSaveAs(const QString& fileName = "", const bool saveSilently=false);
 protected slots:	
 	void fileClose();
 	void fileCloseAll();
@@ -300,6 +301,8 @@ protected slots:
 	void StructureContextMenu(const QPoint& point);
 	void structureContextMenuCloseDocument();
 	void structureContextMenuSwitchMasterDocument();
+	void structureContextMenuExpandSubitems();
+	void structureContextMenuCollapseSubitems();
 	void SymbolGridContextMenu(QWidget* widget, const QPoint& point);
 	void MostUsedSymbolsTriggered(bool direct=false);
 	void symbolAddFavorite();
